<?php

class Uspay{

  private $event;
  private $request;

  public function __construct(UspayEvent $event, $request){

    $this->event = $event;
    $this->request = $request;

  }

  public function getResult(){

    foreach(array(
      'label',
      'amount',
      'test',
	  'method',
	  'hash',
	  'time',
	  'shop_id',
	  'pay'
    ) as $field){
      
	  if(empty($this->request[$field])){
      
        return $this->GoToUspay();

      }

    }

    $secret_key = Config::MERCHANT_SECRET_KEY;

    $label = (int) $this->request['label'];
    $amount = (double) $this->request['amount'];
	$test = empty($this->request['test']) ? '0' : '1';
	$method = $this->request['method'];
	$hash = $this->request['hash'];
	$time = $this->request['time'];
	$shop_id = (int) $this->request['shop_id'];
    $pay = (int) $this->request['pay'];
    

    $hash_calc = hash('sha256',$shop_id.$amount.$secret_key.$label.$pay);

  
    if($hash_calc !== $hash){
      
      return $this->getResponseError('Не верный HASH платежа');

    }

    $uspayModel = UspayModel::getInstance();

    if($uspayModel->getPaymentByUspayId($pay)){

      return $this->getResponseSuccess('Платеж уже существует');

    }

    $itemsCount = floor($amount / Config::ITEM_PRICE);

    if($itemsCount <= 0){

      return $this->getResponseError('Суммы ' . $amount . ' руб. не достаточно для оплаты товара стоимостью ' . Config::ITEM_PRICE . ' руб.');

    }

    if(!$uspayModel->createPayment($uid, $us_account, $amount, $itemsCount)){

      return $this->getResponseError('Возникла ошибка при создании платежа в базе данных');

    }

    $checkResult = $this->event->check($this->request);

    if($checkResult !== true){

      return $this->getResponseError($checkResult);

    }

    $payment = $uspayModel->getPaymentByUspayId($uid);

    if($payment && $payment->status == 1){

      return $this->getResponseSuccess('Платеж уже был оплачен');

    }

    if(!$uspayModel->confirmPaymentByUspayId($uid)){

      return $this->getResponseError('Возникла ошибка при подтверждении платежа');

    }

    $this->event->pay($this->request);

    return $this->getResponseSuccess('ok');

  }

  private function GoToUspay(){

    $post_data = array(
      'shop_id' => Config::MERCHANT_ID,
      'amount' => number_format($this->request['sum'], 2, '.', ''),
      'desc' => 'Пополнение счета',
      'label' => time(),
      'method' => ''
    );

	
    $query_data = http_build_query(array(
	  'id_shop' => $post_data['shop_id'],
	  'summa' => $post_data['amount'],
	  'desc' => $post_data['desc'],
	  'label' => $post_data['label'],
	  'hash' => Config::MERCHANT_PUBLIC_KEY
	  ));

		$pay_id = file_get_contents(Config::MERCHANT_URL . "?" . $query_data);
    header('Location: https://pay.uspay.ru/merchant/'.intval($pay_id));

    return;

  }

  private function getResponseSuccess($message){

    return $message;

  }

  private function getResponseError($message){

    return $message;

  }

}